@@ -17,8 +17,7 @@ from courseware.models import StudentModule
 
 from django.core.files import File
 from django.core.files.storage import default_storage
-from django.template.context import Context
-from django.template.loader import get_template
+from django.template import Context, Template
 
 from webob.response import Response
 
@@ -42,7 +41,8 @@ class StaffGradedAssignmentXBlock(XBlock):
     display_name = String(
         default='Staff Graded Assignment', scope=Scope.settings,
         help="This name appears in the horizontal navigation at the top of "
-             "the page.")
+             "the page."
+    )
 
     weight = Float(
         display_name="Problem Weight",
@@ -50,76 +50,88 @@ class StaffGradedAssignmentXBlock(XBlock):
               "If the value is not set, the problem is worth the sum of the "
               "option point values."),
         values={"min": 0, "step": .1},
-        scope=Scope.settings)
+        scope=Scope.settings
+    )
 
     points = Float(
         display_name="Maximum score",
         help=("Maximum grade score given to assignment by staff."),
         values={"min": 0, "step": .1},
         default=100,
-        scope=Scope.settings)
+        scope=Scope.settings
+    )
 
     score = Float(
         display_name="Grade score",
         default=None,
         help=("Grade score given to assignment by staff."),
         values={"min": 0, "step": .1},
-        scope=Scope.user_state)
+        scope=Scope.user_state
+    )
 
     score_published = Boolean(
         display_name="Whether score has been published.",
         help=("This is a terrible hack, an implementation detail."),
         default=True,
-        scope=Scope.user_state)
+        scope=Scope.user_state
+    )
 
     comment = String(
         display_name="Instructor comment",
         default='',
         scope=Scope.user_state,
-        help="Feedback given to student by instructor.")
+        help="Feedback given to student by instructor."
+    )
 
     uploaded_sha1 = String(
         display_name="Upload SHA1",
         scope=Scope.user_state,
         default=None,
-        help="sha1 of the file uploaded by the student for this assignment.")
+        help="sha1 of the file uploaded by the student for this assignment."
+    )
 
     uploaded_filename = String(
         display_name="Upload file name",
         scope=Scope.user_state,
         default=None,
-        help="The name of the file uploaded for this assignment.")
+        help="The name of the file uploaded for this assignment."
+    )
 
     uploaded_mimetype = String(
         display_name="Mime type of uploaded file",
         scope=Scope.user_state,
         default=None,
-        help="The mimetype of the file uploaded for this assignment.")
+        help="The mimetype of the file uploaded for this assignment."
+    )
 
     uploaded_timestamp = DateTime(
         display_name="Timestamp",
         scope=Scope.user_state,
         default=None,
-        help="When the file was uploaded")
+        help="When the file was uploaded"
+    )
 
     annotated_sha1 = String(
         display_name="Annotated SHA1",
         scope=Scope.user_state,
         default=None,
         help=("sha1 of the annotated file uploaded by the instructor for "
-              "this assignment."))
+              "this assignment.")
+    )
 
     annotated_filename = String(
         display_name="Annotated file name",
         scope=Scope.user_state,
         default=None,
-        help="The name of the annotated file uploaded for this assignment.")
+        help="The name of the annotated file uploaded for this assignment."
+    )
 
     annotated_mimetype = String(
         display_name="Mime type of annotated file",
         scope=Scope.user_state,
         default=None,
-        help="The mimetype of the annotated file uploaded for this assignment.")
+        help="The mimetype of the annotated file uploaded for this assignment."
+    )
 
     annotated_timestamp = DateTime(
         display_name="Timestamp",
@@ -146,14 +158,20 @@ class StaffGradedAssignmentXBlock(XBlock):
             })
             self.score_published = True
 
-        template = get_template("staff_graded_assignment/show.html")
         context = {
             "student_state": json.dumps(self.student_state()),
-            "id": self.location.name
+            "id": self.location.name.replace('.', '_')
         }
         if self.show_staff_grading_interface():
             context['is_course_staff'] = True
-        fragment = Fragment(template.render(Context(context)))
+
+        fragment = Fragment()
+        fragment.add_content(
+            render_template(
+                'templates/staff_graded_assignment/show.html',
+                context
+            )
+        )
         fragment.add_css(_resource("static/css/edx_sga.css"))
         fragment.add_javascript(_resource("static/js/src/edx_sga.js"))
         fragment.initialize_js('StaffGradedAssignmentXBlock')
@@ -205,7 +223,8 @@ class StaffGradedAssignmentXBlock(XBlock):
 
         query = StudentModule.objects.filter(
             course_id=self.xmodule_runtime.course_id,
-            module_state_key=self.location)
+            module_state_key=self.location
+        )
 
         return {
             'assignments': [get_student_data(module) for module in query],
@@ -215,6 +234,7 @@ class StaffGradedAssignmentXBlock(XBlock):
     def studio_view(self, context=None):
         try:
             cls = type(self)
+
             def none_to_empty(x):
                 return x if x is not None else ''
             edit_fields = (
@@ -222,16 +242,23 @@ class StaffGradedAssignmentXBlock(XBlock):
                 for field, validator in (
                     (cls.display_name, 'string'),
                     (cls.points, 'number'),
-                    (cls.weight, 'number')))
+                    (cls.weight, 'number'))
+            )
 
-            template = get_template("staff_graded_assignment/edit.html")
-            fragment = Fragment(template.render(Context({
-                "fields": edit_fields
-            })))
+            context = {
+                'fields': edit_fields
+            }
+            fragment = Fragment()
+            fragment.add_content(
+                render_template(
+                    'templates/staff_graded_assignment/edit.html',
+                    context
+                )
+            )
             fragment.add_javascript(_resource("static/js/src/studio.js"))
             fragment.initialize_js('StaffGradedAssignmentXBlock')
             return fragment
-        except:  #pragma NO COVER
+        except:  # pragma: NO COVER
             log.error("Don't swallow my exceptions", exc_info=True)
             raise
 
@@ -249,7 +276,10 @@ class StaffGradedAssignmentXBlock(XBlock):
         self.uploaded_mimetype = mimetypes.guess_type(upload.file.name)[0]
         self.uploaded_timestamp = _now()
         path = _file_storage_path(
-            self.location.to_deprecated_string(), self.uploaded_sha1, self.uploaded_filename)
+            self.location.to_deprecated_string(),
+            self.uploaded_sha1,
+            self.uploaded_filename
+        )
         if not default_storage.exists(path):
             default_storage.save(path, File(upload.file))
         return Response(json_body=self.student_state())
@@ -260,11 +290,17 @@ class StaffGradedAssignmentXBlock(XBlock):
         upload = request.params['annotated']
         module = StudentModule.objects.get(pk=request.params['module_id'])
         state = json.loads(module.state)
-        state['annotated_sha1'] = sha1 =  _get_sha1(upload.file)
+        state['annotated_sha1'] = sha1 = _get_sha1(upload.file)
         state['annotated_filename'] = filename = upload.file.name
         state['annotated_mimetype'] = mimetypes.guess_type(upload.file.name)[0]
-        state['annotated_timestamp'] = _now().strftime(DateTime.DATETIME_FORMAT);
-        path = _file_storage_path(self.location.to_deprecated_string(), sha1, filename)
+        state['annotated_timestamp'] = _now().strftime(
+            DateTime.DATETIME_FORMAT
+        )
+        path = _file_storage_path(
+            self.location.to_deprecated_string(),
+            sha1,
+            filename
+        )
         if not default_storage.exists(path):
             default_storage.save(path, File(upload.file))
         module.state = json.dumps(state)
@@ -274,18 +310,28 @@ class StaffGradedAssignmentXBlock(XBlock):
     @XBlock.handler
     def download_assignment(self, request, suffix=''):
         path = _file_storage_path(
-            self.location.to_deprecated_string(), self.uploaded_sha1, self.uploaded_filename)
-        return self.download(path,
+            self.location.to_deprecated_string(),
+            self.uploaded_sha1,
+            self.uploaded_filename
+        )
+        return self.download(
+            path,
             self.uploaded_mimetype,
-            self.uploaded_filename)
+            self.uploaded_filename
+        )
 
     @XBlock.handler
     def download_annotated(self, request, suffix=''):
         path = _file_storage_path(
-            self.location.to_deprecated_string(), self.annotated_sha1, self.annotated_filename)
-        return self.download(path,
+            self.location.to_deprecated_string(),
+            self.annotated_sha1,
+            self.annotated_filename
+        )
+        return self.download(
+            path,
             self.annotated_mimetype,
-            self.annotated_filename)
+            self.annotated_filename
+        )
 
     @XBlock.handler
     def staff_download(self, request, suffix=''):
@@ -293,11 +339,15 @@ class StaffGradedAssignmentXBlock(XBlock):
         module = StudentModule.objects.get(pk=request.params['module_id'])
         state = json.loads(module.state)
         path = _file_storage_path(
-            module.module_state_key.to_deprecated_string(), state['uploaded_sha1'],
-            state['uploaded_filename'])
-        return self.download(path,
+            module.module_state_key.to_deprecated_string(),
+            state['uploaded_sha1'],
+            state['uploaded_filename']
+        )
+        return self.download(
+            path,
             state['uploaded_mimetype'],
-            state['uploaded_filename'])
+            state['uploaded_filename']
+        )
 
     @XBlock.handler
     def staff_download_annotated(self, request, suffix=''):
@@ -305,14 +355,18 @@ class StaffGradedAssignmentXBlock(XBlock):
         module = StudentModule.objects.get(pk=request.params['module_id'])
         state = json.loads(module.state)
         path = _file_storage_path(
-            module.module_state_key.to_deprecated_string(), state['annotated_sha1'],
-            state['annotated_filename'])
-        return self.download(path,
+            module.module_state_key.to_deprecated_string(),
+            state['annotated_sha1'],
+            state['annotated_filename']
+        )
+        return self.download(
+            path,
             state['annotated_mimetype'],
-            state['annotated_filename'])
+            state['annotated_filename']
+        )
 
     def download(self, path, mimetype, filename):
-        BLOCK_SIZE = 2**10 * 8 # 8kb
+        BLOCK_SIZE = 2**10 * 8  # 8kb
         file = default_storage.open(path)
         app_iter = iter(partial(file.read, BLOCK_SIZE), '')
         return Response(
@@ -336,11 +390,11 @@ class StaffGradedAssignmentXBlock(XBlock):
         module.state = json.dumps(state)
 
         # This is how we'd like to do it.  See student_view
-        #self.runtime.publish(self, 'grade', {
-        #    'value': state['score'],
-        #    'max_value': self.max_score(),
-        #    'user_id': module.student.id
-        #})
+        # self.runtime.publish(self, 'grade', {
+        #     'value': state['score'],
+        #     'max_value': self.max_score(),
+        #     'user_id': module.student.id
+        # })
 
         module.save()
         return Response(json_body=self.staff_grading_data())
@@ -386,7 +440,7 @@ def _file_storage_path(url, sha1, filename):
 
 
 def _get_sha1(file):
-    BLOCK_SIZE = 2**10 * 8 # 8kb
+    BLOCK_SIZE = 2**10 * 8  # 8kb
     sha1 = hashlib.sha1()
     for block in iter(partial(file.read, BLOCK_SIZE), ''):
         sha1.update(block)
@@ -394,7 +448,7 @@ def _get_sha1(file):
     return sha1.hexdigest()
 
 
-def _resource(path):  # pragma NO COVER
+def _resource(path):  # pragma: NO COVER
     """Handy helper for getting resources from our kit."""
     data = pkg_resources.resource_string(__name__, path)
     return data.decode("utf8")
@@ -402,3 +456,20 @@ def _resource(path):  # pragma NO COVER
 
 def _now():
     return datetime.datetime.utcnow().replace(tzinfo=pytz.utc)
+
+
+def load_resource(resource_path):
+    """
+    Gets the content of a resource
+    """
+    resource_content = pkg_resources.resource_string(__name__, resource_path)
+    return unicode(resource_content)
+
+
+def render_template(template_path, context={}):
+    """
+    Evaluate a template by resource path, applying the provided context
+    """
+    template_str = load_resource(template_path)
+    template = Template(template_str)
+    return template.render(Context(context))
