@@ -41,7 +41,9 @@ class DummyUpload(object):
 class StaffGradedAssignmentXblockTests(unittest.TestCase):
 
     def setUp(self):
-        self.course_id = SlashSeparatedCourseKey.from_deprecated_string('foo/bar/baz')
+        self.course_id = SlashSeparatedCourseKey.from_deprecated_string(
+            'foo/bar/baz'
+        )
         self.runtime = mock.Mock(course_id=self.course_id)
         self.scope_ids = mock.Mock()
         tmp = tempfile.mkdtemp()
@@ -55,7 +57,9 @@ class StaffGradedAssignmentXblockTests(unittest.TestCase):
         from edx_sga.sga import StaffGradedAssignmentXBlock as cls
         field_data = DictFieldData(kw)
         block = cls(self.runtime, field_data, self.scope_ids)
-        block.location = Location('org', 'course', 'run', 'category', 'name', 'revision')
+        block.location = Location(
+            'org', 'course', 'run', 'category', 'name', 'revision'
+        )
         block.xmodule_runtime = self.runtime
         return block
 
@@ -67,7 +71,7 @@ class StaffGradedAssignmentXblockTests(unittest.TestCase):
         module = StudentModule(
             module_state_key=block.location,
             student=user,
-            course_id= self.course_id,
+            course_id=self.course_id,
             state=json.dumps(state))
         module.save()
 
@@ -94,14 +98,18 @@ class StaffGradedAssignmentXblockTests(unittest.TestCase):
         self.assertEqual(block.max_score(), 20)
 
     @mock.patch('edx_sga.sga._resource', DummyResource)
-    @mock.patch('edx_sga.sga.get_template')
+    @mock.patch('edx_sga.sga.render_template')
     @mock.patch('edx_sga.sga.Fragment')
-    def test_student_view(self, Fragment, get_template):
+    def test_student_view(self, Fragment, render_template):
         block = self.make_one()
         fragment = block.student_view()
-        get_template.assert_called_once_with(
-            "staff_graded_assignment/show.html")
-        context = get_template.return_value.render.call_args[0][0]
+        render_template.assert_called_once
+        template_arg = render_template.call_args[0][0]
+        self.assertEqual(
+            template_arg,
+            'templates/staff_graded_assignment/show.html'
+        )
+        context = render_template.call_args[0][1]
         self.assertEqual(context['is_course_staff'], True)
         self.assertEqual(context['id'], 'name')
         student_state = json.loads(context['student_state'])
@@ -119,9 +127,8 @@ class StaffGradedAssignmentXblockTests(unittest.TestCase):
             "StaffGradedAssignmentXBlock")
 
     @mock.patch('edx_sga.sga._resource', DummyResource)
-    @mock.patch('edx_sga.sga.get_template')
     @mock.patch('edx_sga.sga.Fragment')
-    def test_student_view_publish_grade(self, Fragment, get_template):
+    def test_student_view_publish_grade(self, Fragment):
         block = self.make_one(score=9, points=10, score_published=False)
         block.student_view()
         self.runtime.publish.assert_called_once_with(block, 'grade', {
@@ -129,36 +136,40 @@ class StaffGradedAssignmentXblockTests(unittest.TestCase):
         self.assertEqual(block.score_published, True)
 
     @mock.patch('edx_sga.sga._resource', DummyResource)
-    @mock.patch('edx_sga.sga.get_template')
+    @mock.patch('edx_sga.sga.render_template')
     @mock.patch('edx_sga.sga.Fragment')
-    def test_student_view_with_upload(self, Fragment, get_template):
+    def test_student_view_with_upload(self, Fragment, render_template):
         block = self.make_one(uploaded_sha1='foo', uploaded_filename='foo.bar')
         block.student_view()
-        context = get_template.return_value.render.call_args[0][0]
+        context = render_template.call_args[0][1]
         student_state = json.loads(context['student_state'])
         self.assertEqual(student_state['uploaded'], {'filename': 'foo.bar'})
 
     @mock.patch('edx_sga.sga._resource', DummyResource)
-    @mock.patch('edx_sga.sga.get_template')
+    @mock.patch('edx_sga.sga.render_template')
     @mock.patch('edx_sga.sga.Fragment')
-    def test_student_view_with_annotated(self, Fragment, get_template):
+    def test_student_view_with_annotated(self, Fragment, render_template):
         block = self.make_one(
             annotated_sha1='foo', annotated_filename='foo.bar')
         block.student_view()
-        context = get_template.return_value.render.call_args[0][0]
+        context = render_template.call_args[0][1]
         student_state = json.loads(context['student_state'])
         self.assertEqual(student_state['annotated'], {'filename': 'foo.bar'})
 
     @mock.patch('edx_sga.sga._resource', DummyResource)
-    @mock.patch('edx_sga.sga.get_template')
+    @mock.patch('edx_sga.sga.render_template')
     @mock.patch('edx_sga.sga.Fragment')
-    def test_studio_view(self, Fragment, get_template):
+    def test_studio_view(self, Fragment, render_template):
         block = self.make_one()
         fragment = block.studio_view()
-        get_template.assert_called_once_with(
-            "staff_graded_assignment/edit.html")
+        render_template.assert_called_once
+        template_arg = render_template.call_args[0][0]
+        self.assertEqual(
+            template_arg,
+            'templates/staff_graded_assignment/edit.html'
+        )
         cls = type(block)
-        context = get_template.return_value.render.call_args[0][0]
+        context = render_template.call_args[0][1]
         self.assertEqual(tuple(context['fields']), (
             (cls.display_name, 'Staff Graded Assignment', 'string'),
             (cls.points, 100, 'number'),
